==> biodiv_4_1-2.zip: plugins/biodiv/lang/requete_fr.php <==
<?php

/*******************************************************************************\
 * BIODIV, plugin et squelette pour SPIP - https://www.spip.net/               *
 *         dédié à la gestion d'observations naturalistes                      *
 *                                                                             *
 *         Copyright (C) 2008-2024 Renaud LAURETTE                             *
 *                                                                             *
 * BIODIV a été développé initialement pour le projet Biodiv.Balma de l'APCVEB *
 * (Association de Protection du Cadre de Vie et de l'Environnement balmanais) * 
 *     voir Biodiv.Balma : https://balma.biodiv.fr/                            *
 *     voir APCVEB : https://apcveb.fr/                                        *
 *                                                                             *
 *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.         *
 *  Pour plus de détails voir les fichiers COPYING.txt et LICENCE-BIODIV.md    *
\*******************************************************************************/

// This is a SPIP language file  --  Ceci est un fichier langue de SPIP

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'champ_descriptif_explication' => 'Description de la requête',
	'champ_descriptif_label' => 'Descriptif',
	'champ_titre_explication' => 'Nom de la requête',
	'champ_titre_label' => 'Titre',
	
	// E
	'echec_enregistrement' => 'Echec lors de l\'enregistrement de la requête @rq@',
	'enregistrer_requete' => 'Enregistrer la requête en tant que document',
	
	// R
	'resultat' => 'Résultat de recherche avancée',
	
	// S
	'succes_enregistrement' => 'Requête enregistrée dans le document @doc@',

);

==> biodiv_4_4_0.zip: plugins/biodiv/lang/requete_fr.php <==
<?php

/*******************************************************************************\
 * BIODIV, plugin et squelette pour SPIP - https://www.spip.net/               *
 *         dédié à la gestion d'observations naturalistes                      *
 *                                                                             *
 *         Copyright (C) 2008-2024 Renaud LAURETTE                             *
 *                                                                             *
 * BIODIV a été développé initialement pour le projet Biodiv.Balma de l'APCVEB *
 * (Association de Protection du Cadre de Vie et de l'Environnement balmanais) * 
 *     voir Biodiv.Balma : https://balma.biodiv.fr/                            *
 *     voir APCVEB : https://apcveb.fr/                                        *
 *                                                                             *
 *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.         *
 *  Pour plus de détails voir les fichiers COPYING.txt et LICENCE-BIODIV.md    *
\*******************************************************************************/

// This is a SPIP language file  --  Ceci est un fichier langue de SPIP

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'champ_descriptif_explication' => 'Description de la requête',
	'champ_descriptif_label' => 'Descriptif',
	'champ_titre_explication' => 'Nom de la requête',
	'champ_titre_label' => 'Titre',
	'champ_mois_label' => 'Mois de l\'observation',
	
	// E
	'echec_enregistrement' => 'Echec lors de l\'enregistrement de la requête @rq@',
	'enregistrer_requete' => 'Enregistrer la requête en tant que document',
	
	// M
	'mois_01' => 'Janvier',
	'mois_02' => 'Février',
	'mois_03' => 'Mars',
	'mois_04' => 'Avril',
	'mois_05' => 'Mai',
	'mois_06' => 'Juin',
	'mois_07' => 'Juillet',
	'mois_08' => 'Août',
	'mois_09' => 'Septembre',
	'mois_10' => 'Octobre',
	'mois_11' => 'Novembre',
	'mois_12' => 'Décembre',
	
	// R
	'resultat' => 'Résultat de recherche avancée',
	
	// S
	'succes_enregistrement' => 'Requête enregistrée dans le document @doc@',

);
